from __future__ import annotations


def _t(input: str) -> str:
    return input
